utils

package
v0.0.0-...-857c71f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 2, 2024 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsEmpty

func IsEmpty[T comparable](v T) bool

func IsEnabled

func IsEnabled(key bool) func(c echo.Context) bool

func PanicIfErr

func PanicIfErr(prefix string, err error)

func SetIfEmpty

func SetIfEmpty[T comparable](dest *T, value T)

Types

This section is empty.

Directories

Path Synopsis
Package pagi provides utilities for implementing pagination in Go applications.
Package pagi provides utilities for implementing pagination in Go applications.

Jump to